determine outliers
Usage
determine_outliers(
median_correlations = NULL,
outlier_fraction = NULL,
cor_weight = 1,
frac_weight = 1,
only_high = TRUE
)Details
For outlier sample detection, one should first generate median correlations using `median_correlations`, and outlier fractions using `outlier_fraction`. If you only have one or the other, than you should use named arguments to only pass the one or the other.
Alternatively, you can change the weighting used for median correlations or outlier fraction, including setting them to 0.